package net.antonioshome.clexec;

import java.io.File;
import java.io.IOException;
import java.util.concurrent.Future;

/**
 * ProcessExecutor is responsible for executing a Command Line in Java.
 * @author Antonio Vieiro (antonio@antonioshome.net)
 * @author $Author: $
 * @version $Revision: $
 */
public interface ProcessExecutor
{

  /**
   * Executes the given command line in the underlying operating system.
   * @param anInputOutput an object used to redirect the stdin, stdout and stderr
   * of the command to specific Java Input and Output streams.
   * @param aWorkingDirectory a working directory, or null to use Java's default
   *   working directory.
   * @param aCommandLine the command line to execute, specifying the command
   *   to execute and its arguments.
   * @return A Future&lt;Integer&gt; representing the running process. The Integer
   *  returned by the Future object represents the exit value of the running
   *  process.
   * @throws java.io.IOException If a problem happens while launching the
   *   command (such as command not found, etc.)
   */
  public Future<Integer> execute(ProcessStreams anInputOutput, File aWorkingDirectory, String aCommandLine )
    throws IOException;
}
